@@ -10,16 +10,16 @@ import (
 	"strings"
 	"time"
 
+	tea "github.com/charmbracelet/bubbletea"
+	"github.com/charmbracelet/lipgloss"
+	"github.com/charmbracelet/x/ansi"
+	"github.com/sahilm/fuzzy"
+
 	"github.com/charmbracelet/bubbles/help"
 	"github.com/charmbracelet/bubbles/key"
 	"github.com/charmbracelet/bubbles/paginator"
 	"github.com/charmbracelet/bubbles/spinner"
 	"github.com/charmbracelet/bubbles/textinput"
-	tea "github.com/charmbracelet/bubbletea"
-	"github.com/charmbracelet/lipgloss"
-	"github.com/muesli/reflow/ansi"
-	"github.com/muesli/reflow/truncate"
-	"github.com/sahilm/fuzzy"
 )
 
 // Item is an item that appears in the list.
@@ -53,6 +53,7 @@ type ItemDelegate interface {
 }
 
 type filteredItem struct {
+	index   int   // index in the unfiltered list
 	item    Item  // item matched
 	matches []int // rune indices of matched items
 }
@@ -270,6 +271,34 @@ func (m *Model) SetShowTitle(v bool) {
 	m.updatePagination()
 }
 
+// SetFilterText explicitly sets the filter text without relying on user input.
+// It also sets the filterState to a sane default of FilterApplied, but this
+// can be changed with SetFilterState.
+func (m *Model) SetFilterText(filter string) {
+	m.filterState = Filtering
+	m.FilterInput.SetValue(filter)
+	cmd := filterItems(*m)
+	msg := cmd()
+	fmm, _ := msg.(FilterMatchesMsg)
+	m.filteredItems = filteredItems(fmm)
+	m.filterState = FilterApplied
+	m.Paginator.Page = 0
+	m.cursor = 0
+	m.FilterInput.CursorEnd()
+	m.updatePagination()
+	m.updateKeybindings()
+}
+
+// SetFilterState allows setting the filtering state manually.
+func (m *Model) SetFilterState(state FilterState) {
+	m.Paginator.Page = 0
+	m.cursor = 0
+	m.filterState = state
+	m.FilterInput.CursorEnd()
+	m.FilterInput.Focus()
+	m.updateKeybindings()
+}
+
 // ShowTitle returns whether or not the title bar is set to be rendered.
 func (m Model) ShowTitle() bool {
 	return m.showTitle
@@ -456,12 +485,26 @@ func (m Model) MatchesForItem(index int) []int {
 	return m.filteredItems[index].matches
 }
 
-// Index returns the index of the currently selected item as it appears in the
-// entire slice of items.
+// Index returns the index of the currently selected item as it is stored in the
+// filtered list of items.
+// Using this value with SetItem() might be incorrect, consider using
+// GlobalIndex() instead.
 func (m Model) Index() int {
 	return m.Paginator.Page*m.Paginator.PerPage + m.cursor
 }
 
+// GlobalIndex returns the index of the currently selected item as it is stored
+// in the unfiltered list of items. This value can be used with SetItem().
+func (m Model) GlobalIndex() int {
+	index := m.Index()
+
+	if m.filteredItems == nil || index >= len(m.filteredItems) {
+		return index
+	}
+
+	return m.filteredItems[index].index
+}
+
 // Cursor returns the index of the cursor on the current page.
 func (m Model) Cursor() int {
 	return m.cursor
@@ -532,12 +575,12 @@ func (m *Model) CursorDown() {
 }
 
 // PrevPage moves to the previous page, if available.
-func (m Model) PrevPage() {
+func (m *Model) PrevPage() {
 	m.Paginator.PrevPage()
 }
 
 // NextPage moves to the next page, if available.
-func (m Model) NextPage() {
+func (m *Model) NextPage() {
 	m.Paginator.NextPage()
 }
 
@@ -679,7 +722,7 @@ func (m Model) itemsAsFilterItems() filteredItems {
 
 // Set keybindings according to the filter state.
 func (m *Model) updateKeybindings() {
-	switch m.filterState {
+	switch m.filterState { //nolint:exhaustive
 	case Filtering:
 		m.KeyMap.CursorUp.SetEnabled(false)
 		m.KeyMap.CursorDown.SetEnabled(false)
@@ -1050,7 +1093,7 @@ func (m Model) View() string {
 func (m Model) titleView() string {
 	var (
 		view          string
-		titleBarStyle = m.Styles.TitleBar.Copy()
+		titleBarStyle = m.Styles.TitleBar
 
 		// We need to account for the size of the spinner, even if we don't
 		// render it, to reserve some space for it should we turn it on later.
@@ -1075,7 +1118,7 @@ func (m Model) titleView() string {
 		// Status message
 		if m.filterState != Filtering {
 			view += "  " + m.statusMessage
-			view = truncate.StringWithTail(view, uint(m.width-spinnerWidth), ellipsis)
+			view = ansi.Truncate(view, m.width-spinnerWidth, ellipsis)
 		}
 	}
 
@@ -1110,7 +1153,7 @@ func (m Model) statusView() string {
 
 	itemsDisplay := fmt.Sprintf("%d %s", visibleItems, itemName)
 
-	if m.filterState == Filtering {
+	if m.filterState == Filtering { //nolint:nestif
 		// Filter results
 		if visibleItems == 0 {
 			status = m.Styles.StatusEmpty.Render("Nothing matched")
@@ -1126,7 +1169,7 @@ func (m Model) statusView() string {
 
 		if filtered {
 			f := strings.TrimSpace(m.FilterInput.Value())
-			f = truncate.StringWithTail(f, 10, "…")
+			f = ansi.Truncate(f, 10, "…") //nolint:mnd
 			status += fmt.Sprintf("“%s” ", f)
 		}
 
@@ -1143,7 +1186,7 @@ func (m Model) statusView() string {
 }
 
 func (m Model) paginationView() string {
-	if m.Paginator.TotalPages < 2 { //nolint:gomnd
+	if m.Paginator.TotalPages < 2 { //nolint:mnd
 		return ""
 	}
 
@@ -1151,14 +1194,14 @@ func (m Model) paginationView() string {
 
 	// If the dot pagination is wider than the width of the window
 	// use the arabic paginator.
-	if ansi.PrintableRuneWidth(s) > m.width {
+	if ansi.StringWidth(s) > m.width {
 		m.Paginator.Type = paginator.Arabic
 		s = m.Styles.ArabicPagination.Render(m.Paginator.View())
 	}
 
 	style := m.Styles.PaginationStyle
 	if m.delegate.Spacing() == 0 && style.GetMarginTop() == 0 {
-		style = style.Copy().MarginTop(1)
+		style = style.MarginTop(1)
 	}
 
 	return style.Render(s)
@@ -1228,6 +1271,7 @@ func filterItems(m Model) tea.Cmd {
 		filterMatches := []filteredItem{}
 		for _, r := range m.Filter(m.FilterInput.Value(), targets) {
 			filterMatches = append(filterMatches, filteredItem{
+				index:   r.Index,
 				item:    items[r.Index],
 				matches: r.MatchedIndexes,
 			})
@@ -1282,10 +1326,3 @@ func countEnabledBindings(groups [][]key.Binding) (agg int) {
 	}
 	return agg
 }
-
-func max(a, b int) int {
-	if a > b {
-		return a
-	}
-	return b
-}
