@@ -2,22 +2,16 @@
 package stopwatch
 
 import (
-	"sync"
+	"sync/atomic"
 	"time"
 
 	tea "github.com/charmbracelet/bubbletea"
 )
 
-var (
-	lastID int
-	idMtx  sync.Mutex
-)
+var lastID int64
 
 func nextID() int {
-	idMtx.Lock()
-	defer idMtx.Unlock()
-	lastID++
-	return lastID
+	return int(atomic.AddInt64(&lastID, 1))
 }
 
 // TickMsg is a message that is sent on every timer tick.
@@ -29,7 +23,8 @@ type TickMsg struct {
 	// Note, however, that a stopwatch will reject ticks from other
 	// stopwatches, so it's safe to flow all TickMsgs through all stopwatches
 	// and have them still behave appropriately.
-	ID int
+	ID  int
+	tag int
 }
 
 // StartStopMsg is sent when the stopwatch should start or stop.
@@ -47,6 +42,7 @@ type ResetMsg struct {
 type Model struct {
 	d       time.Duration
 	id      int
+	tag     int
 	running bool
 
 	// How long to wait before every tick. Defaults to 1 second.
@@ -79,9 +75,9 @@ func (m Model) Init() tea.Cmd {
 
 // Start starts the stopwatch.
 func (m Model) Start() tea.Cmd {
-	return tea.Batch(func() tea.Msg {
+	return tea.Sequence(func() tea.Msg {
 		return StartStopMsg{ID: m.id, running: true}
-	}, tick(m.id, m.Interval))
+	}, tick(m.id, m.tag, m.Interval))
 }
 
 // Stop stops the stopwatch.
@@ -128,8 +124,17 @@ func (m Model) Update(msg tea.Msg) (Model, tea.Cmd) {
 		if !m.running || msg.ID != m.id {
 			break
 		}
+
+		// If a tag is set, and it's not the one we expect, reject the message.
+		// This prevents the stopwatch from receiving too many messages and
+		// thus ticking too fast.
+		if msg.tag > 0 && msg.tag != m.tag {
+			return m, nil
+		}
+
 		m.d += m.Interval
-		return m, tick(m.id, m.Interval)
+		m.tag++
+		return m, tick(m.id, m.tag, m.Interval)
 	}
 
 	return m, nil
@@ -145,8 +150,8 @@ func (m Model) View() string {
 	return m.d.String()
 }
 
-func tick(id int, d time.Duration) tea.Cmd {
+func tick(id int, tag int, d time.Duration) tea.Cmd {
 	return tea.Tick(d, func(_ time.Time) tea.Msg {
-		return TickMsg{ID: id}
+		return TickMsg{ID: id, tag: tag}
 	})
 }
